==> nextcloud-app-deck-1:1.10.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/th.js <==
OC.L10N.register(
    "deck",
    {
    "Personal" : "ส่วนตัว",
    "Finished" : "เสร็จสิ้น",
    "copy" : "คัดลอก",
    "Done" : "เสร็จสิ้น",
    "The file was uploaded" : "ไฟล์อัปโหลดแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัปโหลดมีขนาดใหญ่เกินค่า MAX_FILE_SIZE ที่ระบุไว้ในรูปแบบของ HTML",
    "The file was only partially uploaded" : "ไฟล์ถูกอัปโหลดเพียงบางส่วน",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัปโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวขาดหาย",
    "Could not write file to disk" : "ไม่สามารถเขียนไฟล์ลงดิสก์",
    "A PHP extension stopped the file upload" : "ส่วนขยาย PHP ได้หยุดการอัปโหลดไฟล์",
    "Card not found" : "ไม่พบการ์ด",
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น ปปปป-ดด-วว",
    "Cancel" : "ยกเลิก",
    "Close" : "ปิด",
    "File already exists" : "ไฟล์นี้มีอยู่แล้ว",
    "Add list" : "เพิ่มรายการ",
    "Overdue" : "เกินกำหนด",
    "Details" : "รายละเอียด",
    "Sharing" : "การแชร์",
    "Tags" : "แท็ก",
    "Undo" : "เลิกทำ",
    "Can edit" : "สามารถแก้ไข",
    "Can share" : "สามารถแชร์",
    "Owner" : "เจ้าของ",
    "Delete" : "ลบ",
    "Transfer" : "โอนย้าย",
    "Delete list" : "ลบรายการ",
    "Edit" : "แก้ไข",
    "Download" : "ดาวน์โหลด",
    "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
    "Attachments" : "ไฟล์แนบ",
    "Comments" : "ความคิดเห็น",
    "Modified" : "แก้ไขเมื่อ",
    "Due date" : "วันที่ครบกำหนด",
    "Today" : "วันนี้",
    "Tomorrow" : "พรุ่งนี้",
    "Save" : "บันทึก",
    "Reply" : "ตอบกลับ",
    "Update" : "อัปเดต",
    "Description" : "รายละเอียด",
    "(group)" : "(กลุ่ม)",
    "seconds ago" : "วินาทีที่ผ่านมา",
    "Shared with you" : "แชร์กับคุณ",
    "Edit board" : "แก้ไขกระดาน",
    "Delete board" : "ลบกระดาน",
    "An error occurred" : "เกิดข้อผิดพลาด",
    "Share" : "แชร์"
},
"nplurals=1; plural=0;");

==> nextcloud-app-deck-1:1.11.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/th.js <==
OC.L10N.register(
    "deck",
    {
    "Personal" : "ส่วนตัว",
    "Finished" : "เสร็จสิ้น",
    "copy" : "คัดลอก",
    "Done" : "เสร็จสิ้น",
    "The file was uploaded" : "ไฟล์อัปโหลดแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัปโหลดมีขนาดใหญ่เกินค่า MAX_FILE_SIZE ที่ระบุไว้ในรูปแบบของ HTML",
    "The file was only partially uploaded" : "ไฟล์ถูกอัปโหลดเพียงบางส่วน",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัปโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวขาดหาย",
    "Could not write file to disk" : "ไม่สามารถเขียนไฟล์ลงดิสก์",
    "A PHP extension stopped the file upload" : "ส่วนขยาย PHP ได้หยุดการอัปโหลดไฟล์",
    "Card not found" : "ไม่พบการ์ด",
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น ปปปป-ดด-วว",
    "Cancel" : "ยกเลิก",
    "File already exists" : "ไฟล์นี้มีอยู่แล้ว",
    "Add list" : "เพิ่มรายการ",
    "Overdue" : "เกินกำหนด",
    "Details" : "รายละเอียด",
    "Sharing" : "การแชร์",
    "Tags" : "แท็ก",
    "Activity" : "กิจกรรม",
    "Undo" : "เลิกทำ",
    "Can edit" : "สามารถแก้ไข",
    "Can share" : "สามารถแชร์",
    "Owner" : "เจ้าของ",
    "Delete" : "ลบ",
    "Transfer" : "โอนย้าย",
    "Delete list" : "ลบรายการ",
    "Edit" : "แก้ไข",
    "Download" : "ดาวน์โหลด",
    "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
    "Attachments" : "ไฟล์แนบ",
    "Comments" : "ความคิดเห็น",
    "Modified" : "แก้ไขเมื่อ",
    "Save" : "บันทึก",
    "Reply" : "ตอบกลับ",
    "Update" : "อัปเดต",
    "Created:" : "สร้างเมื่อ:",
    "Description" : "รายละเอียด",
    "Completed" : "เสร็จแล้ว",
    "(group)" : "(กลุ่ม)",
    "seconds ago" : "วินาทีที่ผ่านมา",
    "Shared with you" : "แชร์กับคุณ",
    "Edit board" : "แก้ไขกระดาน",
    "No notifications" : "ไม่มีการแจ้งเตือน",
    "Delete board" : "ลบกระดาน",
    "An error occurred" : "เกิดข้อผิดพลาด",
    "Today" : "วันนี้",
    "Tomorrow" : "พรุ่งนี้",
    "Close" : "ปิด",
    "Share" : "แชร์",
    "Due date" : "วันที่ครบกำหนด"
},
"nplurals=1; plural=0;");
